summaryrefslogtreecommitdiffstatshomepage
path: root/src/osd
diff options
context:
space:
mode:
author hap <happppp@users.noreply.github.com>2024-02-17 14:31:43 +0100
committer hap <happppp@users.noreply.github.com>2024-02-17 14:31:54 +0100
commit2156f510bc50f690acb6befaf2300657b67f12f2 (patch)
tree0d341eaa1529d3a02765c3ba83886b838a8a7185 /src/osd
parentb21cdc8d2552fdd341df8a322e67e704bfd95983 (diff)
osdsdl: move prescale keys from ctrl+f6/f7 to alt+f8/f9
Diffstat (limited to 'src/osd')
-rw-r--r--src/osd/mac/window.cpp4
-rw-r--r--src/osd/sdl/osdsdl.cpp28
-rw-r--r--src/osd/sdl/window.cpp4
3 files changed, 18 insertions, 18 deletions
diff --git a/src/osd/mac/window.cpp b/src/osd/mac/window.cpp
index b3ab9083a90..d3ec18b94a7 100644
--- a/src/osd/mac/window.cpp
+++ b/src/osd/mac/window.cpp
@@ -223,7 +223,7 @@ void mac_window_info::modify_prescale(int dir)
{
int new_prescale = prescale();
- if (dir > 0 && prescale() < 3)
+ if (dir > 0 && prescale() < 8)
new_prescale = prescale() + 1;
if (dir < 0 && prescale() > 1)
new_prescale = prescale() - 1;
@@ -243,7 +243,7 @@ void mac_window_info::modify_prescale(int dir)
notify_changed();
m_prescale = new_prescale;
}
- machine().ui().popup_time(1, "Prescale %d", prescale());
+ machine().ui().popup_time(1, "Prescale %d/8", prescale());
}
}
diff --git a/src/osd/sdl/window.cpp b/src/osd/sdl/window.cpp
index 41f0c5af2be..41f3b1addc7 100644
--- a/src/osd/sdl/window.cpp
+++ b/src/osd/sdl/window.cpp
@@ -266,7 +266,7 @@ void sdl_window_info::modify_prescale(int dir)
{
int new_prescale = prescale();
- if (dir > 0 && prescale() < 3)
+ if (dir > 0 && prescale() < 20)
new_prescale = prescale() + 1;
if (dir < 0 && prescale() > 1)
new_prescale = prescale() - 1;
@@ -286,7 +286,7 @@ void sdl_window_info::modify_prescale(int dir)
m_prescale = new_prescale;
notify_changed();
}
- machine().ui().popup_time(1, "Prescale %d", prescale());
+ machine().ui().popup_time(1, "Prescale %d/20", prescale());
}
}
diff --git a/src/osd/sdl/osdsdl.cpp b/src/osd/sdl/osdsdl.cpp
index f9778f0ab52..2d3e5e4f02c 100644
--- a/src/osd/sdl/osdsdl.cpp
+++ b/src/osd/sdl/osdsdl.cpp
@@ -343,10 +343,10 @@ void sdl_osd_interface::customize_input_type_list(std::vector<input_type_entry>
entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_PGDN);
break;
// OSD hotkeys use LCTRL and start at F3, they start at
// F3 because F1-F2 are hardcoded into many drivers to
// various dipswitches, and pressing them together with
// LCTRL will still press/toggle these dipswitches.
// LALT-F10 to toggle OpenGL filtering
case IPT_OSD_5:
@@ -359,26 +359,26 @@ void sdl_osd_interface::customize_input_type_list(std::vector<input_type_entry>
entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F10, input_seq::not_code, KEYCODE_LALT);
break;
// LCTRL-F6 to decrease OpenGL prescaling
case IPT_OSD_6:
entry.configure_osd("DECREASE_PRESCALE", N_p("input-name", "Decrease Prescaling"));
- entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F6, KEYCODE_LCONTROL);
+ entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F8, KEYCODE_LALT);
break;
- // add a Not LCTRL condition to the save state key
- case IPT_UI_SAVE_STATE:
- entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F6, input_seq::not_code, KEYCODE_LCONTROL, input_seq::not_code, KEYCODE_LSHIFT, input_seq::not_code, KEYCODE_RSHIFT);
+ // add a Not LALT condition to the frameskip dec key
+ case IPT_UI_FRAMESKIP_DEC:
+ entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F8, input_seq::not_code, KEYCODE_LALT, input_seq::not_code, KEYCODE_LSHIFT, input_seq::not_code, KEYCODE_RSHIFT);
break;
// LCTRL-F7 to increase OpenGL prescaling
case IPT_OSD_7:
entry.configure_osd("INCREASE_PRESCALE", N_p("input-name", "Increase Prescaling"));
- entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F7, KEYCODE_LCONTROL);
+ entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F9, KEYCODE_LALT);
break;
- // add a Not LCTRL condition to the load state key
- case IPT_UI_LOAD_STATE:
- entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F7, input_seq::not_code, KEYCODE_LCONTROL, input_seq::not_code, KEYCODE_LSHIFT, input_seq::not_code, KEYCODE_RSHIFT);
+ // add a Not LALT condition to the load state key
+ case IPT_UI_FRAMESKIP_INC:
+ entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F9, input_seq::not_code, KEYCODE_LALT);
break;
// LSHIFT-LALT-F12 for fullscreen video (BGFX)
@@ -695,7 +695,7 @@ void sdl_osd_interface::check_osd_inputs()
if (USE_OPENGL)
{
- //FIXME: on a per window basis
+ // FIXME: on a per window basis
if (machine().ui_input().pressed(IPT_OSD_5))
{
video_config.filter = !video_config.filter;
@@ -343,10 +343,10 @@ void sdl_osd_interface::customize_input_type_list(std::vector<input_type_entry>
entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_PGDN);
break;
- // OSD hotkeys use LCTRL and start at F3, they start at
- // F3 because F1-F2 are hardcoded into many drivers to
+ // OSD hotkeys use LALT/LCTRL and start at F3, they start
+ // at F3 because F1-F2 are hardcoded into many drivers to
// various dipswitches, and pressing them together with
@@ -343,10 +343,10 @@ void sdl_osd_interface::customize_input_type_list(std::vector<input_type_entry>
// various dipswitches, and pressing them together with
- // LCTRL will still press/toggle these dipswitches.
+ // LALT/LCTRL will still press/toggle these dipswitches.
// LALT-F10 to toggle OpenGL filtering
case IPT_OSD_5:
@@ -359,26 +359,26 @@ void sdl_osd_interface::customize_input_type_list(std::vector<input_type_entry>
entry.defseq(SEQ_TYPE_STANDARD).set(KEYCODE_F10, input_seq::not_code, KEYCODE_LALT);
break;
- // LCTRL-F6 to decrease OpenGL prescaling
+ // LALT-F8 to decrease OpenGL prescaling
case IPT_OSD_6:
entry.configure_osd("DECREASE_PRESCALE", N_p("input-name", "Decrease Prescaling"));
@@ -359,26 +359,26 @@ void sdl_osd_interface::customize_input_type_list(std::vector<input_type_entry>
break;
- // LCTRL-F7 to increase OpenGL prescaling
+ // LALT-F9 to increase OpenGL prescaling
case IPT_OSD_7:
entry.configure_osd("INCREASE_PRESCALE", N_p("input-name", "Increase Prescaling"));